==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ClassFieldAnalysis.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.ClassFieldAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class adde65059c1a016 soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$ScanMethod$3b97bf05420d3a57(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$getFieldInfo$ba2df0c2a0280112(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootField$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$internalTransform$06e9ccd05237f2e2(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootClass$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$ScanMethod$3b97bf05420d3a57;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$getFieldInfo$ba2df0c2a0280112;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$internalTransform$06e9ccd05237f2e2;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$v$38d134a2f84e6813(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods {
	void	(*ScanMethod$3b97bf05420d3a57)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *);
	struct _jc_java_lang_Object$object	*(*getFieldInfo$ba2df0c2a0280112)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootField$object *);
	void	(*internalTransform$06e9ccd05237f2e2)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootClass$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs {
	struct _jc_object	*classToFieldInfoMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs {
	jboolean	final__5fin;
	jboolean	private__5fin;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ClassFieldAnalysis.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.ClassFieldAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class adde65059c1a016 soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootField$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$ScanMethod$3b97bf05420d3a57(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$getFieldInfo$ba2df0c2a0280112(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$internalTransform$06e9ccd05237f2e2(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$ScanMethod$3b97bf05420d3a57;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$getFieldInfo$ba2df0c2a0280112;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$internalTransform$06e9ccd05237f2e2;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$method$v$38d134a2f84e6813(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods {
	void	(*ScanMethod$3b97bf05420d3a57)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getFieldInfo$ba2df0c2a0280112)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$06e9ccd05237f2e2)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vmethods	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs {
	struct _jc_object	*classToFieldInfoMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs {
	jboolean	final__5fin;
	jboolean	private__5fin;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ClassFieldAnalysis_H_ */
